#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-dynamic-statements
version:              0.3.1.2
visibility:           public
id:                   hasql-dynamic-statements-0.3.1.2-KquAmDz3BuFEC3Z6XsFSs8
key:                  hasql-dynamic-statements-0.3.1.2-KquAmDz3BuFEC3Z6XsFSs8
license:              MIT
copyright:            (c) 2019, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-dynamic-statements
synopsis:             Toolkit for constructing Hasql statements dynamically
description:
    This library introduces into the Hasql ecosystem a new abstraction named Snippet,
    which makes it trivial to construct SQL, while injecting values.
    It is intended to be used when the SQL of your statement depends on the parameters,
    that you want to pass in.

abi:                  88480f98725f11a84eda3719268e83f9
exposed:              True
exposed-modules:
    Hasql.DynamicStatements.Session Hasql.DynamicStatements.Snippet
    Hasql.DynamicStatements.Statement

hidden-modules:
    Hasql.DynamicStatements.Prelude
    Hasql.DynamicStatements.Snippet.Defs

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hasql-dynamic-statements-0.3.1.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hasql-dynamic-statements-0.3.1.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hasql-dynamic-statements-0.3.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-dynamic-statements
hs-libraries:         HShasql-dynamic-statements-0.3.1.2-KquAmDz3BuFEC3Z6XsFSs8
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    hasql-1.6.1.1-1ShMEf1LaCYLa7QIOrbaMK
    hasql-implicits-0.1.0.5-EMjzLFiSHP8LnSpgswFsSL
    ptr-0.16.8.7-HuahMvsZaq5FofcfY1Vv4a

haddock-interfaces:
    /usr/share/doc/haskell-hasql-dynamic-statements/html/hasql-dynamic-statements.haddock

haddock-html:         /usr/share/doc/haskell-hasql-dynamic-statements/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

